@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+__author__ = r'wsb310@gmail.com'
+
 import os
 import ssl
 import aiohttp
@@ -72,9 +74,9 @@ def _json_decoder(val, **kwargs):
 
 class Result(dict):
 
-    def __init__(self, status, headers, body):
+    def __init__(self, status, headers, cookies, body):
 
-        super().__init__(status=status, headers=headers, body=body)
+        super().__init__(status=status, headers=headers, cookies=cookies, body=body)
 
     def __bool__(self):
 
@@ -90,6 +92,11 @@ class Result(dict):
 
         return self.get(r'headers')
 
+    @property
+    def cookies(self):
+
+        return self.get(r'cookies')
+
     @property
     def body(self):
 
@@ -112,6 +119,16 @@ class _HTTPClient:
         self._session_config[r'timeout'] = timeout if timeout is not None else DEFAULT_TIMEOUT
         self._session_config.setdefault(r'raise_for_status', True)
 
+    def _encode_body(self, headers, data):
+
+        if headers is None:
+            headers = {}
+
+        if isinstance(data, dict):
+            headers.setdefault(r'Content-Type', r'application/x-www-form-urlencoded')
+
+        return headers, data
+
     async def _handle_response(self, response):
 
         return await response.read()
@@ -150,14 +167,7 @@ class _HTTPClient:
 
         response = None
 
-        if headers is None:
-            headers = {}
-
-        if isinstance(data, dict):
-            headers.setdefault(
-                r'Content-Type',
-                r'application/x-www-form-urlencoded'
-            )
+        headers, data = self._encode_body(headers, data)
 
         settings[r'data'] = data
         settings[r'params'] = params
@@ -185,6 +195,7 @@ class _HTTPClient:
                         response = Result(
                             _response.status,
                             dict(_response.headers),
+                            {key: val.value for key, val in _response.cookies.items()},
                             await self._handle_response(_response)
                         )
 
@@ -243,6 +254,22 @@ class _HTTPJsonMixin:
         return await response.json(encoding=r'utf-8', loads=_json_decoder, content_type=None)
 
 
+class _HTTPJsonRequestMixin(_HTTPJsonMixin):
+    """Json请求模式混入类
+    """
+
+    def _encode_body(self, headers, data):
+
+        if headers is None:
+            headers = {}
+
+        if isinstance(data, dict):
+            headers.setdefault(r'Content-Type', r'application/json')
+            data = Utils.json_encode(data)
+
+        return headers, data
+
+
 class _HTTPTouchMixin:
     """Touch模式混入类，不接收body数据
     """
@@ -353,6 +380,12 @@ class HTTPJsonClient(_HTTPJsonMixin, HTTPClient):
     pass
 
 
+class HTTPJsonRequestClient(_HTTPJsonRequestMixin, HTTPClient):
+    """HTTP客户端，Json请求模式
+    """
+    pass
+
+
 class HTTPTouchClient(_HTTPTouchMixin, HTTPClient):
     """HTTP客户端，Touch模式
     """
@@ -400,6 +433,12 @@ class HTTPJsonClientPool(_HTTPJsonMixin, HTTPClientPool):
     pass
 
 
+class HTTPJsonRequestClientPool(_HTTPJsonRequestMixin, HTTPClientPool):
+    """HTTP带连接池客户端，Json请求模式
+    """
+    pass
+
+
 class HTTPTouchClientPool(_HTTPTouchMixin, HTTPClientPool):
     """HTTP带连接池客户端，Touch模式
     """
