@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+__author__ = r'wsb310@gmail.com'
+
 import pytz
 import logging
 
@@ -123,6 +125,77 @@ class CronTask(TaskAbstract):
         )
 
 
+class DCSCronTask(TaskInterface):
+
+    def __init__(self, redis_pool, name, crontab, func, *args, **kwargs):
+
+        self._name = name
+
+        self._task_lock = redis_pool.get_client().allocate_lock(f'dcs_cron_task/{name}', 60)
+        self._task_func = func
+
+        self._heartbeat = IntervalTask.create(30, self._do_heartbeat)
+        self._cron_task = CronTask.create(crontab, self._do_job, *args, **kwargs)
+
+    @property
+    def name(self):
+
+        return self._name
+
+    async def _do_heartbeat(self):
+
+        resp = await self._check_status()
+
+        Utils.log.debug(f'dcs cron task heartbeat: {self._name} => {resp}')
+
+    async def _check_status(self):
+
+        if await self._task_lock.acquire():
+            return True
+        else:
+            return False
+
+    async def _do_job(self, *args, **kwargs):
+
+        if await self._check_status():
+
+            Utils.log.info(f'dcs cron task start: {self._name}')
+
+            if Utils.is_coroutine_function(self._task_func):
+                await self._task_func(*args, **kwargs)
+            else:
+                self._task_func(*args, **kwargs)
+
+            Utils.log.info(f'dcs cron task finish: {self._name}')
+
+        else:
+
+            Utils.log.debug(f'dcs cron task idle: {self._name}')
+
+    def start(self, min_delay=30, max_delay=60):
+
+        delay = Utils.randint(min_delay, max_delay)
+
+        def _func():
+            self._heartbeat.start()
+            self._cron_task.start()
+            Utils.log.info(f'dcs cron task init: {self._name}, delay: {delay}')
+
+        if delay == 0:
+            _func()
+        else:
+            Utils.call_later(delay, _func)
+
+    def stop(self):
+
+        self._heartbeat.stop()
+        self._cron_task.stop()
+
+    def is_running(self):
+
+        return self._cron_task.is_running()
+
+
 class RateLimiter:
     """流量控制器，用于对计算资源的保护
     添加任务append函数如果成功会返回Future对象，可以通过await该对象等待执行结果
