@@ -4,13 +4,12 @@ __author__ = r'wsb310@gmail.com'
 
 from inspect import Signature, Parameter
 
-from pydantic.main import BaseModel as _BaseModel
-from pydantic.main import ModelMetaclass as _ModelMetaclass
+from pydantic import main as base_cls
 
-from fastapi.params import Param
+from fastapi import params
 
 
-class ModelMetaclass(_ModelMetaclass):
+class ModelMetaclass(base_cls.ModelMetaclass):
 
     def __init__(cls, _what, _bases=None, _dict=None):
 
@@ -25,10 +24,6 @@ class ModelMetaclass(_ModelMetaclass):
 
             for field in cls.__fields__.values():
 
-                # 如果不是Param参数类型的子类，则不写入签名
-                if not isinstance(field.field_info, Param):
-                    continue
-
                 func_params.append(
                     Parameter(
                         field.name, Parameter.POSITIONAL_OR_KEYWORD,
@@ -37,13 +32,20 @@ class ModelMetaclass(_ModelMetaclass):
                     )
                 )
 
-            # 更新类方法签名
-            cls.dependency = lambda **kwargs: kwargs
-            cls.dependency.__signature__ = Signature(func_params)
+            # 更新类方法
+            cls.params = lambda **kwargs: kwargs
+            cls.params.__signature__ = Signature(func_params)
 
 
-class BaseModel(_BaseModel, metaclass=ModelMetaclass):
+class BaseModel(base_cls.BaseModel, metaclass=ModelMetaclass):
+    pass
 
-    @staticmethod
-    def dependency(**kwargs):
-        return kwargs
+
+class Depends(params.Depends):
+
+    def __init__(self, dependency=None, *, use_cache=True):
+
+        if hasattr(dependency, r'params') and callable(dependency.params):
+            super().__init__(dependency=dependency.params, use_cache=use_cache)
+        else:
+            super().__init__(dependency=dependency, use_cache=use_cache)
